]> granicus.if.org Git - neomutt/commitdiff
replace 'NNTP_DATA' with 'struct NntpData'
authorRichard Russon <rich@flatcap.org>
Tue, 16 May 2017 13:18:32 +0000 (14:18 +0100)
committerRichard Russon <rich@flatcap.org>
Tue, 16 May 2017 14:21:29 +0000 (15:21 +0100)
browser.c
browser.h
complete.c
curs_main.c
mx.c
newsrc.c
nntp.c
nntp.h
pager.c
send.c

index 2c006c1a30695d5c54a20943b44d8f36a0efa6a1..65b8c7b2d03b983dfe6440628edfae5c37db9010 100644 (file)
--- a/browser.c
+++ b/browser.c
@@ -600,7 +600,7 @@ static void add_folder(struct Menu *m, struct browser_state *state, const char *
 #endif
 #ifdef USE_NNTP
   if (option(OPTNEWS))
-    (state->entry)[state->entrylen].nd = (NNTP_DATA *) data;
+    (state->entry)[state->entrylen].nd = (struct NntpData *) data;
 #endif
   (state->entrylen)++;
 }
@@ -631,7 +631,7 @@ static int examine_directory(struct Menu *menu, struct browser_state *state,
 
     for (i = 0; i < nserv->groups_num; i++)
     {
-      NNTP_DATA *nntp_data = nserv->groups_list[i];
+      struct NntpData *nntp_data = nserv->groups_list[i];
       if (!nntp_data)
         continue;
       if (prefix && *prefix && (strncmp(prefix, nntp_data->group, strlen(prefix)) != 0))
@@ -757,7 +757,7 @@ static int examine_mailboxes(struct Menu *menu, struct browser_state *state)
 
     for (i = 0; i < nserv->groups_num; i++)
     {
-      NNTP_DATA *nntp_data = nserv->groups_list[i];
+      struct NntpData *nntp_data = nserv->groups_list[i];
       if (nntp_data &&
           (nntp_data->new || (nntp_data->subscribed &&
                               (nntp_data->unread || !option(OPTSHOWONLYUNREAD)))))
@@ -1056,7 +1056,7 @@ void _mutt_select_file(char *f, size_t flen, int flags, char ***files, int *numf
       buffy = 0;
       for (j = 0; j < nserv->groups_num; j++)
       {
-        NNTP_DATA *nntp_data = nserv->groups_list[j];
+        struct NntpData *nntp_data = nserv->groups_list[j];
         if (nntp_data && nntp_data->subscribed)
         {
           buffy = 1;
@@ -1871,7 +1871,7 @@ void _mutt_select_file(char *f, size_t flen, int flags, char ***files, int *numf
         {
           struct folder_file *ff = &state.entry[menu->current];
           int rc;
-          NNTP_DATA *nntp_data = NULL;
+          struct NntpData *nntp_data = NULL;
 
           rc = nntp_newsrc_parse(CurrentNewsSrv);
           if (rc < 0)
@@ -1906,7 +1906,7 @@ void _mutt_select_file(char *f, size_t flen, int flags, char ***files, int *numf
 
           for (j = 0; j < nserv->groups_num; j++)
           {
-            NNTP_DATA *nntp_data = nserv->groups_list[j];
+            struct NntpData *nntp_data = nserv->groups_list[j];
             if (nntp_data)
               nntp_data->deleted = true;
           }
@@ -2002,7 +2002,7 @@ void _mutt_select_file(char *f, size_t flen, int flags, char ***files, int *numf
 
             for (k = 0; nserv && k < nserv->groups_num; k++)
             {
-              NNTP_DATA *nntp_data = nserv->groups_list[k];
+              struct NntpData *nntp_data = nserv->groups_list[k];
               if (nntp_data && nntp_data->group && !nntp_data->subscribed)
               {
                 if (regexec(rx, nntp_data->group, 0, NULL, 0) == 0)
index 3b9d20046b67099f4bb036c7a4bc364a11896cbb..029db3f1d3a2612772c2a890d32d66128745d7cd 100644 (file)
--- a/browser.h
+++ b/browser.h
@@ -47,7 +47,7 @@ struct folder_file
 #endif
   bool has_buffy : 1;
 #ifdef USE_NNTP
-  NNTP_DATA *nd;
+  struct NntpData *nd;
 #endif
   bool local : 1; /* folder is on local filesystem */
   bool tagged : 1;
index 16559196f7e5e23665cac7d2d8a2adacb5842f69..ca280e2e1ade7c294273f1a0857e7d2cb0599eff 100644 (file)
@@ -65,7 +65,7 @@ int mutt_complete(char *s, size_t slen)
     {
       for (; n < nserv->groups_num; n++)
       {
-        NNTP_DATA *nntp_data = nserv->groups_list[n];
+        struct NntpData *nntp_data = nserv->groups_list[n];
 
         if (nntp_data && nntp_data->subscribed)
         {
@@ -79,7 +79,7 @@ int mutt_complete(char *s, size_t slen)
 
     for (; n < nserv->groups_num; n++)
     {
-      NNTP_DATA *nntp_data = nserv->groups_list[n];
+      struct NntpData *nntp_data = nserv->groups_list[n];
 
       if (nntp_data && nntp_data->subscribed &&
           (mutt_strncmp(nntp_data->group, filepart, len) == 0))
index 0be908d08782c264da8d1bfddca8996c16edeb6b..203cd4f74f4009a1fd39d900b846432db51cce0b 100644 (file)
@@ -2790,7 +2790,7 @@ int mutt_index_menu(void)
         CHECK_ATTACH
         if (Context && Context->magic == MUTT_NNTP)
         {
-          NNTP_DATA *nntp_data = Context->data;
+          struct NntpData *nntp_data = Context->data;
           if (mutt_newsgroup_catchup(nntp_data->nserv, nntp_data->group))
             menu->redraw = REDRAW_INDEX | REDRAW_STATUS;
         }
@@ -3073,7 +3073,7 @@ int mutt_index_menu(void)
                              _("Reply by mail as poster prefers?")) != MUTT_YES)
         {
           if (Context && Context->magic == MUTT_NNTP &&
-              !((NNTP_DATA *) Context->data)->allowed && query_quadoption(OPT_TOMODERATED, _("Posting to this group not allowed, may be moderated. Continue?")) != MUTT_YES)
+              !((struct NntpData *) Context->data)->allowed && query_quadoption(OPT_TOMODERATED, _("Posting to this group not allowed, may be moderated. Continue?")) != MUTT_YES)
             break;
           if (op == OP_POST)
             ci_send_message(SENDNEWS, NULL, NULL, Context, NULL);
diff --git a/mx.c b/mx.c
index b6f2a005c619638c2603e0f74f044624d02313bd..c33cb04944d35bddf58c425d626df0dd2f91ca32 100644 (file)
--- a/mx.c
+++ b/mx.c
@@ -829,7 +829,7 @@ int mx_close_mailbox(struct Context *ctx, int *index_hint)
 #ifdef USE_NNTP
   if (ctx->unread && ctx->magic == MUTT_NNTP)
   {
-    NNTP_DATA *nntp_data = ctx->data;
+    struct NntpData *nntp_data = ctx->data;
 
     if (nntp_data && nntp_data->nserv && nntp_data->group)
     {
index e207d66fc793ba0b0fea906fd1bbb3f8cbb511bb..1e363bc420296ff4af53662d3bb8e9a0a66bd95b 100644 (file)
diff --git a/nntp.c b/nntp.c
index 577d3b88e9f8f0eb94ec4db1ee50b2d848db6f52..c6d991cc5f795570e789bb636593ee63150cb037 100644 (file)
--- a/nntp.c
+++ b/nntp.c
@@ -727,7 +727,7 @@ int nntp_open_connection(NNTP_SERVER *nserv)
 }
 
 /* Send data from buffer and receive answer to same buffer */
-static int nntp_query(NNTP_DATA *nntp_data, char *line, size_t linelen)
+static int nntp_query(struct NntpData *nntp_data, char *line, size_t linelen)
 {
   NNTP_SERVER *nserv = nntp_data->nserv;
   char buf[LONG_STRING];
@@ -792,7 +792,7 @@ static int nntp_query(NNTP_DATA *nntp_data, char *line, size_t linelen)
  *  1 - bad response (answer in query buffer)
  * -1 - connection lost
  * -2 - error in funct(*line, *data) */
-static int nntp_fetch_lines(NNTP_DATA *nntp_data, char *query, size_t qlen,
+static int nntp_fetch_lines(struct NntpData *nntp_data, char *query, size_t qlen,
                             char *msg, int (*funct)(char *, void *), void *data)
 {
   int done = false;
@@ -870,7 +870,7 @@ static int nntp_fetch_lines(NNTP_DATA *nntp_data, char *query, size_t qlen,
 static int fetch_description(char *line, void *data)
 {
   NNTP_SERVER *nserv = data;
-  NNTP_DATA *nntp_data = NULL;
+  struct NntpData *nntp_data = NULL;
   char *desc = NULL;
 
   if (!line)
@@ -896,7 +896,7 @@ static int fetch_description(char *line, void *data)
 
 /* Fetch newsgroups descriptions.
  * Returns the same code as nntp_fetch_lines() */
-static int get_description(NNTP_DATA *nntp_data, char *wildmat, char *msg)
+static int get_description(struct NntpData *nntp_data, char *wildmat, char *msg)
 {
   NNTP_SERVER *nserv = NULL;
   char buf[STRING];
@@ -927,7 +927,7 @@ static int get_description(NNTP_DATA *nntp_data, char *wildmat, char *msg)
 /* Update read flag and set article number if empty */
 static void nntp_parse_xref(struct Context *ctx, struct Header *hdr)
 {
-  NNTP_DATA *nntp_data = ctx->data;
+  struct NntpData *nntp_data = ctx->data;
   char *buf = NULL, *p = NULL;
 
   buf = p = safe_strdup(hdr->env->xref);
@@ -1006,7 +1006,7 @@ static int parse_overview_line(char *line, void *data)
 {
   struct FetchCtx *fc = data;
   struct Context *ctx = fc->ctx;
-  NNTP_DATA *nntp_data = ctx->data;
+  struct NntpData *nntp_data = ctx->data;
   struct Header *hdr = NULL;
   FILE *fp = NULL;
   char tempfile[_POSIX_PATH_MAX];
@@ -1155,7 +1155,7 @@ static int parse_overview_line(char *line, void *data)
 /* Fetch headers */
 static int nntp_fetch_headers(struct Context *ctx, void *hc, anum_t first, anum_t last, int restore)
 {
-  NNTP_DATA *nntp_data = ctx->data;
+  struct NntpData *nntp_data = ctx->data;
   struct FetchCtx fc;
   struct Header *hdr = NULL;
   char buf[HUGE_STRING];
@@ -1387,7 +1387,7 @@ static int nntp_fetch_headers(struct Context *ctx, void *hc, anum_t first, anum_
 static int nntp_open_mailbox(struct Context *ctx)
 {
   NNTP_SERVER *nserv = NULL;
-  NNTP_DATA *nntp_data = NULL;
+  struct NntpData *nntp_data = NULL;
   char buf[HUGE_STRING];
   char server[LONG_STRING];
   char *group = NULL;
@@ -1521,7 +1521,7 @@ static int nntp_open_mailbox(struct Context *ctx)
 /* Fetch message */
 static int nntp_fetch_message(struct Context *ctx, struct Message *msg, int msgno)
 {
-  NNTP_DATA *nntp_data = ctx->data;
+  struct NntpData *nntp_data = ctx->data;
   struct NntpAcache *acache = NULL;
   struct Header *hdr = ctx->hdrs[msgno];
   char buf[_POSIX_PATH_MAX];
@@ -1649,7 +1649,7 @@ static int nntp_close_message(struct Context *ctx, struct Message *msg)
 /* Post article */
 int nntp_post(const char *msg)
 {
-  NNTP_DATA *nntp_data, nntp_tmp;
+  struct NntpData *nntp_data, nntp_tmp;
   FILE *fp = NULL;
   char buf[LONG_STRING];
   size_t len;
@@ -1722,7 +1722,7 @@ int nntp_post(const char *msg)
  *  1 - new articles found
  *  0 - no change
  * -1 - lost connection */
-static int nntp_group_poll(NNTP_DATA *nntp_data, int update_stat)
+static int nntp_group_poll(struct NntpData *nntp_data, int update_stat)
 {
   char buf[LONG_STRING] = "";
   anum_t count, first, last;
@@ -1767,7 +1767,7 @@ static int nntp_group_poll(NNTP_DATA *nntp_data, int update_stat)
  * -1           - lost connection */
 static int nntp_check_mailbox(struct Context *ctx, int *index_hint)
 {
-  NNTP_DATA *nntp_data = ctx->data;
+  struct NntpData *nntp_data = ctx->data;
   NNTP_SERVER *nserv = nntp_data->nserv;
   time_t now = time(NULL);
   int i, j;
@@ -1978,7 +1978,7 @@ static int nntp_check_mailbox(struct Context *ctx, int *index_hint)
 /* Save changes to .newsrc and cache */
 static int nntp_sync_mailbox(struct Context *ctx, int *index_hint)
 {
-  NNTP_DATA *nntp_data = ctx->data;
+  struct NntpData *nntp_data = ctx->data;
   int rc, i;
 #ifdef USE_HCACHE
   header_cache_t *hc = NULL;
@@ -2037,7 +2037,7 @@ static int nntp_sync_mailbox(struct Context *ctx, int *index_hint)
 /* Free up memory associated with the newsgroup context */
 static int nntp_fastclose_mailbox(struct Context *ctx)
 {
-  NNTP_DATA *nntp_data = ctx->data, *nntp_tmp = NULL;
+  struct NntpData *nntp_data = ctx->data, *nntp_tmp = NULL;
 
   if (!nntp_data)
     return 0;
@@ -2057,7 +2057,7 @@ static int nntp_date(NNTP_SERVER *nserv, time_t *now)
 {
   if (nserv->hasDATE)
   {
-    NNTP_DATA nntp_data;
+    struct NntpData nntp_data;
     char buf[LONG_STRING];
     struct tm tm;
     memset(&tm, 0, sizeof(tm));
@@ -2088,7 +2088,7 @@ static int nntp_date(NNTP_SERVER *nserv, time_t *now)
 /* Fetch list of all newsgroups from server */
 int nntp_active_fetch(NNTP_SERVER *nserv)
 {
-  NNTP_DATA nntp_data;
+  struct NntpData nntp_data;
   char msg[SHORT_STRING];
   char buf[LONG_STRING];
   unsigned int i;
@@ -2120,7 +2120,7 @@ int nntp_active_fetch(NNTP_SERVER *nserv)
 
   for (i = 0; i < nserv->groups_num; i++)
   {
-    NNTP_DATA *data = nserv->groups_list[i];
+    struct NntpData *data = nserv->groups_list[i];
 
     if (data && data->deleted && !data->newsrc_ent)
     {
@@ -2140,7 +2140,7 @@ int nntp_active_fetch(NNTP_SERVER *nserv)
  * -1 - error */
 int nntp_check_new_groups(NNTP_SERVER *nserv)
 {
-  NNTP_DATA nntp_data;
+  struct NntpData nntp_data;
   time_t now;
   struct tm *tm = NULL;
   char buf[LONG_STRING];
@@ -2157,7 +2157,7 @@ int nntp_check_new_groups(NNTP_SERVER *nserv)
     mutt_message(_("Checking for new messages..."));
     for (i = 0; i < nserv->groups_num; i++)
     {
-      NNTP_DATA *data = nserv->groups_list[i];
+      struct NntpData *data = nserv->groups_list[i];
 
       if (data && data->subscribed)
       {
@@ -2172,7 +2172,7 @@ int nntp_check_new_groups(NNTP_SERVER *nserv)
     if (Context && Context->magic == MUTT_NNTP)
     {
       buf[0] = '\0';
-      if (nntp_query((NNTP_DATA *) Context->data, buf, sizeof(buf)) < 0)
+      if (nntp_query((struct NntpData *) Context->data, buf, sizeof(buf)) < 0)
         return -1;
     }
   }
@@ -2185,7 +2185,7 @@ int nntp_check_new_groups(NNTP_SERVER *nserv)
     return -1;
   nntp_data.nserv = nserv;
   if (Context && Context->magic == MUTT_NNTP)
-    nntp_data.group = ((NNTP_DATA *) Context->data)->group;
+    nntp_data.group = ((struct NntpData *) Context->data)->group;
   else
     nntp_data.group = NULL;
   i = nserv->groups_num;
@@ -2220,7 +2220,7 @@ int nntp_check_new_groups(NNTP_SERVER *nserv)
                          MUTT_PROGRESS_MSG, ReadInc, nserv->groups_num - i);
       for (; i < nserv->groups_num; i++)
       {
-        NNTP_DATA *data = nserv->groups_list[i];
+        struct NntpData *data = nserv->groups_list[i];
 
         if (get_description(data, NULL, NULL) < 0)
           return -1;
@@ -2242,7 +2242,7 @@ int nntp_check_new_groups(NNTP_SERVER *nserv)
  * -1 - error */
 int nntp_check_msgid(struct Context *ctx, const char *msgid)
 {
-  NNTP_DATA *nntp_data = ctx->data;
+  struct NntpData *nntp_data = ctx->data;
   struct Header *hdr = NULL;
   FILE *fp = NULL;
   char tempfile[_POSIX_PATH_MAX];
@@ -2338,7 +2338,7 @@ static int fetch_children(char *line, void *data)
 /* Fetch children of article with the Message-ID */
 int nntp_check_children(struct Context *ctx, const char *msgid)
 {
-  NNTP_DATA *nntp_data = ctx->data;
+  struct NntpData *nntp_data = ctx->data;
   struct ChildCtx cc;
   char buf[STRING];
   int i, rc;
diff --git a/nntp.h b/nntp.h
index 7af3dc0b9a7fecbc6037baaeea84c0df9d5192df..32e9e25e2eb80ce478522bcece1e3f9b48835032 100644 (file)
--- a/nntp.h
+++ b/nntp.h
@@ -89,7 +89,7 @@ struct NntpAcache
   char *path;
 };
 
-typedef struct
+struct NntpData
 {
   char *group;
   char *desc;
@@ -107,7 +107,7 @@ typedef struct
   NNTP_SERVER *nserv;
   struct NntpAcache acache[NNTP_ACACHE_LEN];
   struct BodyCache *bcache;
-} NNTP_DATA;
+};
 
 typedef struct
 {
@@ -123,19 +123,19 @@ int nntp_active_save_cache(NNTP_SERVER *nserv);
 int nntp_check_new_groups(NNTP_SERVER *nserv);
 int nntp_open_connection(NNTP_SERVER *nserv);
 void nntp_newsrc_gen_entries(struct Context *ctx);
-void nntp_bcache_update(NNTP_DATA *nntp_data);
+void nntp_bcache_update(struct NntpData *nntp_data);
 void nntp_article_status(struct Context *ctx, struct Header *hdr, char *group, anum_t anum);
-void nntp_group_unread_stat(NNTP_DATA *nntp_data);
+void nntp_group_unread_stat(struct NntpData *nntp_data);
 void nntp_data_free(void *data);
-void nntp_acache_free(NNTP_DATA *nntp_data);
-void nntp_delete_group_cache(NNTP_DATA *nntp_data);
+void nntp_acache_free(struct NntpData *nntp_data);
+void nntp_delete_group_cache(struct NntpData *nntp_data);
 
 /* exposed interface */
 NNTP_SERVER *nntp_select_server(char *server, int leave_lock);
-NNTP_DATA *mutt_newsgroup_subscribe(NNTP_SERVER *nserv, char *group);
-NNTP_DATA *mutt_newsgroup_unsubscribe(NNTP_SERVER *nserv, char *group);
-NNTP_DATA *mutt_newsgroup_catchup(NNTP_SERVER *nserv, char *group);
-NNTP_DATA *mutt_newsgroup_uncatchup(NNTP_SERVER *nserv, char *group);
+struct NntpData *mutt_newsgroup_subscribe(NNTP_SERVER *nserv, char *group);
+struct NntpData *mutt_newsgroup_unsubscribe(NNTP_SERVER *nserv, char *group);
+struct NntpData *mutt_newsgroup_catchup(NNTP_SERVER *nserv, char *group);
+struct NntpData *mutt_newsgroup_uncatchup(NNTP_SERVER *nserv, char *group);
 int nntp_active_fetch(NNTP_SERVER *nserv);
 int nntp_newsrc_update(NNTP_SERVER *nserv);
 int nntp_post(const char *msg);
@@ -154,8 +154,8 @@ const char *nntp_format_str(char *dest, size_t destlen, size_t col, int cols,
 NNTP_SERVER *CurrentNewsSrv INITVAL(NULL);
 
 #ifdef USE_HCACHE
-header_cache_t *nntp_hcache_open(NNTP_DATA *nntp_data);
-void nntp_hcache_update(NNTP_DATA *nntp_data, header_cache_t *hc);
+header_cache_t *nntp_hcache_open(struct NntpData *nntp_data);
+void nntp_hcache_update(struct NntpData *nntp_data, header_cache_t *hc);
 #endif
 
 extern struct mx_ops mx_nntp_ops;
diff --git a/pager.c b/pager.c
index cac32d6ef183bb5b333eb0e603eedc3e2724641c..9a3e9d7316fff273b73294a7f664235dabe38521 100644 (file)
--- a/pager.c
+++ b/pager.c
@@ -2813,7 +2813,7 @@ int mutt_pager(const char *banner, const char *fname, int flags, pager_t *extra)
         CHECK_MODE(IsHeader(extra) && !IsAttach(extra));
         CHECK_ATTACH;
         if (extra->ctx && extra->ctx->magic == MUTT_NNTP &&
-            !((NNTP_DATA *) extra->ctx->data)->allowed && query_quadoption(OPT_TOMODERATED, _("Posting to this group not allowed, may be moderated. Continue?")) != MUTT_YES)
+            !((struct NntpData *) extra->ctx->data)->allowed && query_quadoption(OPT_TOMODERATED, _("Posting to this group not allowed, may be moderated. Continue?")) != MUTT_YES)
           break;
         ci_send_message(SENDNEWS, NULL, NULL, extra->ctx, NULL);
         pager_menu->redraw = REDRAW_FULL;
@@ -2823,7 +2823,7 @@ int mutt_pager(const char *banner, const char *fname, int flags, pager_t *extra)
         CHECK_MODE(IsHeader(extra) || IsMsgAttach(extra));
         CHECK_ATTACH;
         if (extra->ctx && extra->ctx->magic == MUTT_NNTP &&
-            !((NNTP_DATA *) extra->ctx->data)->allowed && query_quadoption(OPT_TOMODERATED, _("Posting to this group not allowed, may be moderated. Continue?")) != MUTT_YES)
+            !((struct NntpData *) extra->ctx->data)->allowed && query_quadoption(OPT_TOMODERATED, _("Posting to this group not allowed, may be moderated. Continue?")) != MUTT_YES)
           break;
         if (IsMsgAttach(extra))
           mutt_attach_forward(extra->fp, extra->hdr, extra->idx, extra->idxlen,
@@ -2847,7 +2847,7 @@ int mutt_pager(const char *banner, const char *fname, int flags, pager_t *extra)
                              _("Reply by mail as poster prefers?")) != MUTT_YES)
         {
           if (extra->ctx && extra->ctx->magic == MUTT_NNTP &&
-              !((NNTP_DATA *) extra->ctx->data)->allowed && query_quadoption(OPT_TOMODERATED, _("Posting to this group not allowed, may be moderated. Continue?")) != MUTT_YES)
+              !((struct NntpData *) extra->ctx->data)->allowed && query_quadoption(OPT_TOMODERATED, _("Posting to this group not allowed, may be moderated. Continue?")) != MUTT_YES)
             break;
           if (IsMsgAttach(extra))
             mutt_attach_reply(extra->fp, extra->hdr, extra->idx, extra->idxlen,
diff --git a/send.c b/send.c
index ea0461b4bd45e543d0bd760bf926aaa9339702e6..0e02cf40cddf1347e3db0f7b2b072e0bda063521 100644 (file)
--- a/send.c
+++ b/send.c
@@ -1492,7 +1492,7 @@ int ci_send_message(int flags,      /* send mode */
 
 #ifdef USE_NNTP
     if ((flags & SENDNEWS) && ctx && ctx->magic == MUTT_NNTP && !msg->env->newsgroups)
-      msg->env->newsgroups = safe_strdup(((NNTP_DATA *) ctx->data)->group);
+      msg->env->newsgroups = safe_strdup(((struct NntpData *) ctx->data)->group);
 #endif
 
     if (!(flags & (SENDMAILX | SENDBATCH)) && !(option(OPTAUTOEDIT) && option(OPTEDITHDRS)) &&
--- a/newsrc.c
+++ b/newsrc.c
 #include "hcache/hcache.h"
 #endif
 
-/* Find NNTP_DATA for given newsgroup or add it */
-static NNTP_DATA *nntp_data_find(NNTP_SERVER *nserv, const char *group)
+/* Find NntpData for given newsgroup or add it */
+static struct NntpData *nntp_data_find(NNTP_SERVER *nserv, const char *group)
 {
-  NNTP_DATA *nntp_data = hash_find(nserv->groups_hash, group);
+  struct NntpData *nntp_data = hash_find(nserv->groups_hash, group);
 
   if (!nntp_data)
   {
     int len = strlen(group) + 1;
-    /* create NNTP_DATA structure and add it to hash */
-    nntp_data = safe_calloc(1, sizeof(NNTP_DATA) + len);
-    nntp_data->group = (char *) nntp_data + sizeof(NNTP_DATA);
+    /* create NntpData structure and add it to hash */
+    nntp_data = safe_calloc(1, sizeof(struct NntpData) + len);
+    nntp_data->group = (char *) nntp_data + sizeof(struct NntpData);
     strfcpy(nntp_data->group, group, len);
     nntp_data->nserv = nserv;
     nntp_data->deleted = true;
@@ -60,7 +60,7 @@ static NNTP_DATA *nntp_data_find(NNTP_SERVER *nserv, const char *group)
           hash_resize(nserv->groups_hash, nserv->groups_hash->nelem * 2, 0);
     hash_insert(nserv->groups_hash, nntp_data->group, nntp_data);
 
/* add NNTP_DATA to list */
     if (nserv->groups_num >= nserv->groups_max)
     {
       nserv->groups_max *= 2;
@@ -72,7 +72,7 @@ static NNTP_DATA *nntp_data_find(NNTP_SERVER *nserv, const char *group)
 }
 
 /* Remove all temporarily cache files */
-void nntp_acache_free(NNTP_DATA *nntp_data)
+void nntp_acache_free(struct NntpData *nntp_data)
 {
   int i;
 
@@ -86,10 +86,10 @@ void nntp_acache_free(NNTP_DATA *nntp_data)
   }
 }
 
/* Free NNTP_DATA, used to destroy hash elements */
 void nntp_data_free(void *data)
 {
-  NNTP_DATA *nntp_data = data;
+  struct NntpData *nntp_data = data;
 
   if (!nntp_data)
     return;
@@ -112,7 +112,7 @@ void nntp_newsrc_close(NNTP_SERVER *nserv)
 }
 
 /* calculate number of unread articles using .newsrc data */
-void nntp_group_unread_stat(NNTP_DATA *nntp_data)
+void nntp_group_unread_stat(struct NntpData *nntp_data)
 {
   unsigned int i;
   anum_t first, last;
@@ -193,7 +193,7 @@ int nntp_newsrc_parse(NNTP_SERVER *nserv)
   /* .newsrc has been externally modified or hasn't been loaded yet */
   for (i = 0; i < nserv->groups_num; i++)
   {
-    NNTP_DATA *nntp_data = nserv->groups_list[i];
+    struct NntpData *nntp_data = nserv->groups_list[i];
 
     if (!nntp_data)
       continue;
@@ -209,7 +209,7 @@ int nntp_newsrc_parse(NNTP_SERVER *nserv)
     char *b = NULL, *h = NULL, *p = NULL;
     unsigned int j = 1;
     bool subs = false;
-    NNTP_DATA *nntp_data = NULL;
+    struct NntpData *nntp_data = NULL;
 
     /* find end of newsgroup name */
     p = strpbrk(line, ":!");
@@ -275,7 +275,7 @@ int nntp_newsrc_parse(NNTP_SERVER *nserv)
 /* Generate array of .newsrc entries */
 void nntp_newsrc_gen_entries(struct Context *ctx)
 {
-  NNTP_DATA *nntp_data = ctx->data;
+  struct NntpData *nntp_data = ctx->data;
   anum_t last = 0, first = 1;
   int series, i;
   int save_sort = SORT_ORDER;
@@ -419,7 +419,7 @@ int nntp_newsrc_update(NNTP_SERVER *nserv)
   /* we will generate full newsrc here */
   for (i = 0; i < nserv->groups_num; i++)
   {
-    NNTP_DATA *nntp_data = nserv->groups_list[i];
+    struct NntpData *nntp_data = nserv->groups_list[i];
     unsigned int n;
 
     if (!nntp_data || !nntp_data->newsrc_ent)
@@ -520,7 +520,7 @@ void nntp_expand_path(char *line, size_t len, struct Account *acct)
 int nntp_add_group(char *line, void *data)
 {
   NNTP_SERVER *nserv = data;
-  NNTP_DATA *nntp_data = NULL;
+  struct NntpData *nntp_data = NULL;
   char group[LONG_STRING];
   char desc[HUGE_STRING] = "";
   char mod;
@@ -596,7 +596,7 @@ int nntp_active_save_cache(NNTP_SERVER *nserv)
 
   for (i = 0; i < nserv->groups_num; i++)
   {
-    NNTP_DATA *nntp_data = nserv->groups_list[i];
+    struct NntpData *nntp_data = nserv->groups_list[i];
 
     if (!nntp_data || nntp_data->deleted)
       continue;
@@ -628,7 +628,7 @@ static int nntp_hcache_namer(const char *path, char *dest, size_t destlen)
 }
 
 /* Open newsgroup hcache */
-header_cache_t *nntp_hcache_open(NNTP_DATA *nntp_data)
+header_cache_t *nntp_hcache_open(struct NntpData *nntp_data)
 {
   struct CissUrl url;
   char file[_POSIX_PATH_MAX];
@@ -645,7 +645,7 @@ header_cache_t *nntp_hcache_open(NNTP_DATA *nntp_data)
 }
 
 /* Remove stale cached headers */
-void nntp_hcache_update(NNTP_DATA *nntp_data, header_cache_t *hc)
+void nntp_hcache_update(struct NntpData *nntp_data, header_cache_t *hc)
 {
   char buf[16];
   int old = 0;
@@ -692,7 +692,7 @@ void nntp_hcache_update(NNTP_DATA *nntp_data, header_cache_t *hc)
 /* Remove bcache file */
 static int nntp_bcache_delete(const char *id, struct BodyCache *bcache, void *data)
 {
-  NNTP_DATA *nntp_data = data;
+  struct NntpData *nntp_data = data;
   anum_t anum;
   char c;
 
@@ -707,13 +707,13 @@ static int nntp_bcache_delete(const char *id, struct BodyCache *bcache, void *da
 }
 
 /* Remove stale cached messages */
-void nntp_bcache_update(NNTP_DATA *nntp_data)
+void nntp_bcache_update(struct NntpData *nntp_data)
 {
   mutt_bcache_list(nntp_data->bcache, nntp_bcache_delete, nntp_data);
 }
 
 /* Remove hcache and bcache of newsgroup */
-void nntp_delete_group_cache(NNTP_DATA *nntp_data)
+void nntp_delete_group_cache(struct NntpData *nntp_data)
 {
   if (!nntp_data || !nntp_data->nserv || !nntp_data->nserv->cacheable)
     return;
@@ -759,8 +759,8 @@ void nntp_clear_cache(NNTP_SERVER *nserv)
     {
       char *group = entry->d_name;
       struct stat sb;
-      NNTP_DATA *nntp_data = NULL;
-      NNTP_DATA nntp_tmp;
+      struct NntpData *nntp_data = NULL;
+      struct NntpData nntp_tmp;
 
       if ((mutt_strcmp(group, ".") == 0) || (mutt_strcmp(group, "..") == 0))
         continue;
@@ -879,7 +879,7 @@ NNTP_SERVER *nntp_select_server(char *server, int leave_lock)
   int rc;
   struct Account acct;
   NNTP_SERVER *nserv = NULL;
-  NNTP_DATA *nntp_data = NULL;
+  struct NntpData *nntp_data = NULL;
   struct Connection *conn = NULL;
   struct CissUrl url;
 
@@ -1069,7 +1069,7 @@ NNTP_SERVER *nntp_select_server(char *server, int leave_lock)
  * Old = not read but cached */
 void nntp_article_status(struct Context *ctx, struct Header *hdr, char *group, anum_t anum)
 {
-  NNTP_DATA *nntp_data = ctx->data;
+  struct NntpData *nntp_data = ctx->data;
   unsigned int i;
 
   if (group)
@@ -1100,9 +1100,9 @@ void nntp_article_status(struct Context *ctx, struct Header *hdr, char *group, a
 }
 
 /* Subscribe newsgroup */
-NNTP_DATA *mutt_newsgroup_subscribe(NNTP_SERVER *nserv, char *group)
+struct NntpData *mutt_newsgroup_subscribe(NNTP_SERVER *nserv, char *group)
 {
-  NNTP_DATA *nntp_data = NULL;
+  struct NntpData *nntp_data = NULL;
 
   if (!nserv || !nserv->groups_hash || !group || !*group)
     return NULL;
@@ -1120,9 +1120,9 @@ NNTP_DATA *mutt_newsgroup_subscribe(NNTP_SERVER *nserv, char *group)
 }
 
 /* Unsubscribe newsgroup */
-NNTP_DATA *mutt_newsgroup_unsubscribe(NNTP_SERVER *nserv, char *group)
+struct NntpData *mutt_newsgroup_unsubscribe(NNTP_SERVER *nserv, char *group)
 {
-  NNTP_DATA *nntp_data = NULL;
+  struct NntpData *nntp_data = NULL;
 
   if (!nserv || !nserv->groups_hash || !group || !*group)
     return NULL;
@@ -1141,9 +1141,9 @@ NNTP_DATA *mutt_newsgroup_unsubscribe(NNTP_SERVER *nserv, char *group)
 }
 
 /* Catchup newsgroup */
-NNTP_DATA *mutt_newsgroup_catchup(NNTP_SERVER *nserv, char *group)
+struct NntpData *mutt_newsgroup_catchup(NNTP_SERVER *nserv, char *group)
 {
-  NNTP_DATA *nntp_data = NULL;
+  struct NntpData *nntp_data = NULL;
 
   if (!nserv || !nserv->groups_hash || !group || !*group)
     return NULL;
@@ -1171,9 +1171,9 @@ NNTP_DATA *mutt_newsgroup_catchup(NNTP_SERVER *nserv, char *group)
 }
 
 /* Uncatchup newsgroup */
-NNTP_DATA *mutt_newsgroup_uncatchup(NNTP_SERVER *nserv, char *group)
+struct NntpData *mutt_newsgroup_uncatchup(NNTP_SERVER *nserv, char *group)
 {
-  NNTP_DATA *nntp_data = NULL;
+  struct NntpData *nntp_data = NULL;
 
   if (!nserv || !nserv->groups_hash || !group || !*group)
     return NULL;
@@ -1213,13 +1213,13 @@ void nntp_buffy(char *buf, size_t len)
 
   for (i = 0; i < CurrentNewsSrv->groups_num; i++)
   {
-    NNTP_DATA *nntp_data = CurrentNewsSrv->groups_list[i];
+    struct NntpData *nntp_data = CurrentNewsSrv->groups_list[i];
 
     if (!nntp_data || !nntp_data->subscribed || !nntp_data->unread)
       continue;
 
     if (Context && Context->magic == MUTT_NNTP &&
-        (mutt_strcmp(nntp_data->group, ((NNTP_DATA *) Context->data)->group) == 0))
+        (mutt_strcmp(nntp_data->group, ((struct NntpData *) Context->data)->group) == 0))
     {
       unsigned int j, unread = 0;
 
@@ -60,7 +60,7 @@ static NNTP_DATA *nntp_data_find(NNTP_SERVER *nserv, const char *group)
     hash_insert(nserv->groups_hash, nntp_data->group, nntp_data);
 
-    /* add NNTP_DATA to list */
+    /* add NntpData to list */
     if (nserv->groups_num >= nserv->groups_max)
     {
@@ -86,10 +86,10 @@ void nntp_acache_free(NNTP_DATA *nntp_data)
 }
 
-/* Free NNTP_DATA, used to destroy hash elements */
+/* Free NntpData, used to destroy hash elements */
 void nntp_data_free(void *data)
 {